AuthenticatorSelection class

Represents an authenticator selection

Constructors

AuthenticatorSelection({String? authenticatorAttachment, required bool requireResidentKey, required String residentKey, required String userVerification})

Properties

authenticatorAttachment ↔ String?
The authenticator attachment
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
requireResidentKey ↔ bool
Whether a resident key is required
getter/setter pair
residentKey ↔ String
The resident key
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVerification ↔ String
The user verification
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → AuthenticatorSelection