ExcludeCredential class

Constructors

ExcludeCredential({required String type, required String id})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
The ID
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
The type
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → ExcludeCredential