RegisterResponse class

Represents a register response

Constructors

RegisterResponse({required String id, required String rawId, required String clientDataJSON, required String attestationObject, required List<String?> transports, Map<String?, Object?>? clientExtensionResults = const {}})

Properties

attestationObject ↔ String
The attestation object
getter/setter pair
clientDataJSON ↔ String
The client data JSON
getter/setter pair
clientExtensionResults ↔ Map<String?, Object?>?
The clientExtensionResults - PRF results
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
The ID
getter/setter pair
rawId ↔ String
The raw ID
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transports ↔ List<String?>
The supported transports for the authenticator
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → RegisterResponse