RelyingParty class

Represents a relying party

Constructors

RelyingParty({required String name, required String id})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
ID of the relying party
getter/setter pair
name ↔ String
Name of the relying party
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → RelyingParty