User class

Represents a user

Constructors

User({required String displayName, required String name, required String id, String? icon})

Properties

displayName ↔ String
The display name
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
icon ↔ String?
The icon
getter/setter pair
id ↔ String
The ID
getter/setter pair
name ↔ String
The name
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → User