PasskeysApi class
Constructors
PasskeysApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for PasskeysApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
authenticate (String relyingPartyId , String challenge , int ? timeout , String ? userVerification , List <AllowCredential > ? allowCredentials , bool ? preferImmediatelyAvailableCredentials , String ? salt )
→ Future <AuthenticateResponse >
canAuthenticate ()
→ Future <bool >
cancelCurrentAuthenticatorOperation ()
→ Future <void >
clearRestoreCredential ()
→ Future <void >
createRestoreCredential (String challenge , RelyingParty relyingParty , User user , AuthenticatorSelection ? authenticatorSelection , List <PubKeyCredParam > ? pubKeyCredParams , int ? timeout , String ? attestation , List <ExcludeCredential > excludeCredentials , bool isCloudBackupEnabled )
→ Future <RegisterResponse >
getRestoreCredential (String relyingPartyId , String challenge , int ? timeout , String ? userVerification , List <AllowCredential > ? allowCredentials )
→ Future <AuthenticateResponse >
hasPasskeySupport ()
→ Future <bool >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register (String challenge , RelyingParty relyingParty , User user , AuthenticatorSelection ? authenticatorSelection , List <PubKeyCredParam > ? pubKeyCredParams , int ? timeout , String ? attestation , List <ExcludeCredential > excludeCredentials , String ? salt )
→ Future <RegisterResponse >
signalAllAcceptedCredentials (String relyingPartyId , String userId , List <String > allAcceptedCredentialIds )
→ Future <void >
signalUnknownCredential (String relyingPartyId , String credentialId )
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited